==> mingw-w64-typst-0.3.0-2.src.tar.zst: typst-0.3.0/docs/src/general/community.md <==
---
description: |
  Join the Typst community, get help from other users and have a say in the
  future of Typst.
---

# Community
Hey and welcome to the Community page! We're so glad you're here. Typst is
developed by an early-stage startup and is still in its infancy, but it
would be pointless without people like you who are interested in it.

We would love to not only hear from you but to also provide spaces where you can
discuss any topic around Typst, typesetting, writing, the sciences, and
typography with other likeminded people.

For the time being, **we would like to invite you to our [Discord
server](https://discord.gg/2uDybryKPe).** The server is open for everyone, even
if you do not have preview access to Typst yet. Of course, you are also very
welcome to connect with us on social media
([Twitter](https://twitter.com/typstapp/),
[Instagram](https://instagram.com/typstapp/),
[LinkedIn](https://linkedin.com/company/typst), and
[Github](https://github.com/typst)).

## What to share?
For our community, we want to foster versatility and inclusivity.
You are welcome to post about any topic that you think would interest other
community members, but if you need a little inspiration, here are a few ideas:

- Share and discuss your thoughts and ideas for new features or improvements
  you'd like to see in Typst
- Showcase documents you've created with Typst, or share any unique or creative
  ways you've used the platform
- Share importable files or templates that you use to style your documents
- Alert us of bugs you encounter while using Typst

## Beta test
We are starting a public beta test of our product on March 21st, 2023.
The Typst compiler is still under active development and breaking changes can
occur at any point. The compiler is developed in the open on
[GitHub](https://github.com/typst/typst).

We will update the members of our Discord server and our social media followers
when new features become available in the preview. We'll also update you on the
development progress of large features. A development tracker will become
available on the documentation pages soon.

## Community Rules
We want to make our community a safe and inclusive space for everyone.
Therefore, we will not tolerate any sexual harassment, sexism, political
attacks, derogatory language or personal insults, racism, doxing, and other
inappropriate behavior. We pledge to remove members that are in violation of
these rules. [Contact us](https://typst.app/contact/) if you think another
community member acted inappropriately towards you. All complaints will be
reviewed and investigated promptly and fairly.

In addition, our [privacy policy](https://typst.app/privacy/) applies on all
community spaces operated by us, such as the Discord server. Please also note
that the terms of service and privacy policies of the respective services apply.

## See you soon!
Thanks again for learning more about Typst. We would be delighted to meet you on
our [Discord server](https://discord.gg/2uDybryKPe)!

==> mingw-w64-typst-0.6.0-1.src.tar.zst: typst-0.6.0/docs/src/general/community.md <==
---
description: |
  Join the Typst community, get help from other users and have a say in the
  future of Typst.
---

# Community
Hey and welcome to the Community page! We're so glad you're here. Typst is
developed by an early-stage startup and is still in its infancy, but it
would be pointless without people like you who are interested in it.

We would love to not only hear from you but to also provide spaces where you can
discuss any topic around Typst, typesetting, writing, the sciences, and
typography with other likeminded people.

For the time being, **we would like to invite you to our [Discord
server](https://discord.gg/2uDybryKPe).** The server is open for everyone, even
if you do not have preview access to Typst yet. Of course, you are also very
welcome to connect with us on social media
([Twitter](https://twitter.com/typstapp/),
[Instagram](https://instagram.com/typstapp/),
[LinkedIn](https://linkedin.com/company/typst), and
[GitHub](https://github.com/typst)).

## What to share? { #want-to-share }
For our community, we want to foster versatility and inclusivity.
You are welcome to post about any topic that you think would interest other
community members, but if you need a little inspiration, here are a few ideas:

- Share and discuss your thoughts and ideas for new features or improvements
  you'd like to see in Typst
- Showcase documents you've created with Typst, or share any unique or creative
  ways you've used the platform
- Share importable files or templates that you use to style your documents
- Alert us of bugs you encounter while using Typst

## Beta test { #beta-test }
We are starting a public beta test of our product on March 21st, 2023.
The Typst compiler is still under active development and breaking changes can
occur at any point. The compiler is developed in the open on
[GitHub](https://github.com/typst/typst).

We will update the members of our Discord server and our social media followers
when new features become available in the preview. We'll also update you on the
development progress of large features. A development tracker will become
available on the documentation pages soon.

## How to support Typst { #support-typst }
If you want to support Typst, there are multiple ways to do that! You can
[contribute to the code](https://github.com/typst/typst) or
[translate the strings in Typst](https://github.com/search?q=repo%3Atypst%2Ftypst+impl+LocalName+for&type=code)
to your native language if it's not supported yet. You can also help us by
[sponsoring us!](https://github.com/sponsors/typst) Multiple recurring
sponsorship tiers are available and all of them come with a set of goodies.
No matter how you contribute, thank you for your support!

## Community Rules { #rules }
We want to make our community a safe and inclusive space for everyone.
Therefore, we will not tolerate any sexual harassment, sexism, political
attacks, derogatory language or personal insults, racism, doxing, and other
inappropriate behavior. We pledge to remove members that are in violation of
these rules. [Contact us](https://typst.app/contact/) if you think another
community member acted inappropriately towards you. All complaints will be
reviewed and investigated promptly and fairly.

In addition, our [privacy policy](https://typst.app/privacy/) applies on all
community spaces operated by us, such as the Discord server. Please also note
that the terms of service and privacy policies of the respective services apply.

## See you soon! { #see-you }
Thanks again for learning more about Typst. We would be delighted to meet you on
our [Discord server](https://discord.gg/2uDybryKPe)!
